@@ -58,8 +58,9 @@ def validate_foreign_keys(user, object, user_field_name="user", unchecked_field_
                 if hasattr(object, field.name) and field.name not in unchecked_field_names:
                     related_object = getattr(object, field.name)
                     if related_object:
+                        from guardian_queryset.models import GuardianModel
                         if field.name == user_field_name:
                             if related_object != user:
-                                raise ValidationError("attempted to create foreign key on unauthorized object")
-                        elif not has_view_permissions(user, related_object):
-                            raise ValidationError("attempted to create foreign key on unauthorized object")
\ No newline at end of file
+                                raise ValidationError(f"attempted to create foreign key on unauthorized object {related_object}")
+                        elif isinstance(related_object, GuardianModel) and not has_view_permissions(user, related_object):
+                            raise ValidationError(f"attempted to create foreign key on unauthorized object {related_object}")
\ No newline at end of file
